package cn.com.qmth.export.bean;

import java.io.File;
import java.io.IOException;
import java.util.LinkedHashSet;
import java.util.Map;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import cn.com.qmth.export.Param;

public class MyProducer4 extends Producer {

    private static Logger logger = LogManager.getLogger(MyProducer4.class);

    private static String dir = Param.dataDir;

    private static String paperDir = Param.dataDir + "paper/";

    @Override
    protected void produce(Map<String, Object> param) throws Exception {
        logger.info("***************************任务生产开始");
        File excelFolder = new File(paperDir);
        if (excelFolder.exists()) {
            FileUtil.clearDirectory(paperDir);
        } else {
            excelFolder.mkdirs();
        }
        LinkedHashSet<String> cs = readSubject();
        if (CollectionUtils.isEmpty(cs)) {
            logger.debug("无数据导出");
            return;
        } else {
            logger.debug(cs.size() + "个课程");
        }
        for (String c : cs) {
            offer(new PaperExportDto(c));
        }
        logger.info("***************************任务生产结束");
    }

    private static LinkedHashSet<String> readSubject() {
        LinkedHashSet<String> list = new LinkedHashSet<>();
        XSSFWorkbook wb = null;
        try {
            wb = new XSSFWorkbook(dir + "subject_info.xlsx");
            XSSFSheet sheet = wb.getSheetAt(0);
            int rows = sheet.getLastRowNum();
            for (int i = 1; i <= rows; i++) {
                XSSFRow row = sheet.getRow(i);
                String yunkaiCode;
                try {
                    yunkaiCode = row.getCell(1).getStringCellValue().trim();
                } catch (Exception e) {
                    yunkaiCode = (row.getCell(1).getNumericCellValue() + "").trim();
                }
                list.add(yunkaiCode);
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        } finally {
            if (wb != null) {
                try {
                    wb.close();
                } catch (IOException e) {
                }
            }
        }
        return list;
    }
}
